@@ -39,6 +39,7 @@ SchedulingDialog::SchedulingDialog(const QDate &startDate, const QTime &startTim
     , mResolver(resolver)
     , mPeriodModel(new CalendarSupport::FreePeriodModel(this))
 {
+    setWindowTitle(i18n("Scheduling"));
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QWidget *w = new QWidget(this);
     setupUi(w);
@@ -102,8 +103,8 @@ SchedulingDialog::~SchedulingDialog()
 {
 }
 
-void SchedulingDialog::slotUpdateIncidenceStartEnd(const KDateTime &startDateTime,
-                                                   const KDateTime &endDateTime)
+void SchedulingDialog::slotUpdateIncidenceStartEnd(const QDateTime &startDateTime,
+                                                   const QDateTime &endDateTime)
 {
     mVisualWidget->slotUpdateIncidenceStartEnd(startDateTime, endDateTime);
 }
